@@ -1543,7 +1543,15 @@ class SphinxRenderer:
         signode = addnodes.desc_signature()
         title = node.xreftitle[0] + ':'
         titlenode = nodes.emphasis(text=title)
-        signode += titlenode
+        ref = addnodes.pending_xref(
+            "",
+            reftype="ref",
+            refdomain="std",
+            refexplicit=True,
+            reftarget=node.id,
+            refdoc=self.app.env.docname,
+            *[titlenode])
+        signode += ref
 
         nodelist = self.render(node.xrefdescription)
         contentnode = addnodes.desc_content()
@@ -1556,6 +1564,27 @@ class SphinxRenderer:
 
         return [descnode]
 
+    def visit_docvariablelist(self, node) -> List[Node]:
+        output = []
+        for varlistentry, listitem in zip(node.varlistentries, node.listitems):
+            descnode = addnodes.desc()
+            descnode['objtype'] = 'varentry'
+            signode = addnodes.desc_signature()
+            signode += self.render_optional(varlistentry)
+            descnode += signode
+            contentnode = addnodes.desc_content()
+            contentnode += self.render_iterable(listitem.para)
+            descnode += contentnode
+            output.append(descnode)
+        return output
+
+    def visit_docvarlistentry(self, node) -> List[Node]:
+        content = node.term.content_
+        return self.render_iterable(content)
+
+    def visit_docanchor(self, node) -> List[None]:
+        return self.create_doxygen_target(node)
+
     def visit_mixedcontainer(self, node) -> List[Node]:
         return self.render_optional(node.getValue())
 
@@ -1932,6 +1961,9 @@ class SphinxRenderer:
         "docparamname": visit_docparamname,
         "templateparamlist": visit_templateparamlist,
         "docxrefsect": visit_docxrefsect,
+        "docvariablelist": visit_docvariablelist,
+        "docvarlistentry": visit_docvarlistentry,
+        "docanchor": visit_docanchor,
     }
 
     def render(self, node, context: Optional[RenderContext] = None) -> List[Node]:
